@@ -2,9 +2,9 @@ import argparse
 import logging
 import re
 import sys
-import urllib.request
+from requests import Session
+from requests.adapters import HTTPAdapter
 from pathlib import Path
-
 from bs4 import BeautifulSoup
 import ssl
 import certifi
@@ -72,8 +72,11 @@ def main():
     parser = argparse.ArgumentParser()
     parser.add_argument('file', type=Path)
     parser.add_argument(
-        '-o', '--out', help="name for the generated html file.", nargs='?', const="clang.html", type=str)
- 
+        '-o', '--out', help="Generated html file name.", nargs='?', const="clang.html", default="clang.html", type=str)
+    parser.add_argument(
+        '-d', '--checks_dict_url', help="Override the latest checks list, (e.g., v14.0.0 uses \
+        https://releases.llvm.org/14.0.0/tools/clang/tools/extra/docs/clang-tidy/checks/list.html).", nargs='?', type=str)
+
     try:
         args = parser.parse_args()
     except:
@@ -83,15 +86,23 @@ def main():
 
     tidy_log_lines: Path = args.file
     output_path: Path = Path(args.out)
-    clang_tidy_visualizer(tidy_log_lines, output_path)
+    clang_tidy_visualizer(tidy_log_lines, output_path, args.checks_dict_url)
 
 
 def clang_tidy_visualizer(tidy_log_file: Path,
-                          output_html_file: Path = Path("clang.html")):
+                          output_html_file: Path = Path("clang.html"),
+                          checks_dict_url = None):
     tidy_log_lines = tidy_log_file.read_text().splitlines()
     clang_base_url = "https://clang.llvm.org/extra/clang-tidy/checks/"
     global checks_dict
-    checks_dict = find_checks_dict(clang_base_url)
+
+    if checks_dict_url is None:
+        checks_dict_url = clang_base_url + 'list.html'
+
+    checks_dict = find_checks_dict(checks_dict_url)
+    if checks_dict is None or len(checks_dict) == 0:
+        print("Error! Could not retrieve a dictionary of checks.")
+        exit(0)
     checks_list = list(checks_dict.keys())
     checks_list.sort()
 
@@ -171,22 +182,36 @@ def clang_tidy_visualizer(tidy_log_file: Path,
                         num_used_checks, names_of_used, clang_base_url)
         writeScript(clang_html, num_used_checks)
 
+# adapted from https://github.com/psf/requests/issues/4775#issuecomment-478198879
+class TLSAdapter(HTTPAdapter):
+    def init_poolmanager(self, *args, **kwargs):
+        ctx = ssl.create_default_context(cafile=certifi.where())
+        ctx.set_ciphers('DEFAULT@SECLEVEL=1')
+        kwargs['ssl_context'] = ctx
+        return super(TLSAdapter, self).init_poolmanager(*args, **kwargs)
 
 # Scrape data from clang-tidy's official list of current checks.
-def find_checks_dict(clang_base_url: str):
-    url = clang_base_url + 'list.html'
-    resp = urllib.request.urlopen(
-        url, context=ssl.create_default_context(cafile=certifi.where()))
-    soup = BeautifulSoup(resp, "lxml")
+def find_checks_dict(checks_dict_url: str):
+    session = Session()
+    session.mount('https://', TLSAdapter())
+    try:
+        res = session.get(checks_dict_url)
+    except Exception as e:
+        print(e)
+        return None
 
+    soup = BeautifulSoup(res.text, "lxml")
     scrape_checks_dict = dict()
-    for link in soup.find_all('a', href=True):
+    clang_check_links = soup.find_all('a', href=True)
+
+    for link in clang_check_links:
         match_docs_check_name = re.match(
             "^([a-zA-Z0-9].*).html.*$", link['href'])
         if match_docs_check_name:
             docs_check_name = match_docs_check_name.group(1)
             split_docs_check = docs_check_name.split('/')
-            if len(split_docs_check) == 2:
+            len_split_docs_check = len(split_docs_check)
+            if len_split_docs_check > 0 and len_split_docs_check <= 2:
                 scrape_checks_dict[fromClangDocsName(
                     docs_check_name)] = split_docs_check[0]
     return scrape_checks_dict
@@ -232,7 +257,7 @@ def usage():
         >>> clang_tidy_visualizer(Path("examples/sample.log"))
 
     Optional args:
-    - [-o, --out] or clang_tidy_visualizer(path_to_log: Path, output_path: Path) 
+    - [-o, --out] or clang_tidy_visualizer(path_to_log: Path, output_path: Path)
         - Rename the generated html file. The default filename is stored as "clang.html" in the directory
           from where you call the script.
 
@@ -399,7 +424,7 @@ def writeScript(f, num_used_checks):
                         break;
                 }}
             }}
-            
+
             if (stored_highlights === null || no_previous_state) {{
                 checks_arr[all_checks] = "action";
                 check_hl.classList.add('list-group-item-action');
